@@ -46,11 +46,11 @@ using namespace std;
 #include "hand.h"
 #include "game.h"
 
-hslot_type last_hslot;
-gint last_cardid;
+hslot_type last_hslot = NULL;
+gint last_cardid = -1;
 
-hstack_type last_hstack;
-gint last_chipid;
+hstack_type last_hstack = NULL;
+gint last_chipid = -1;
 
 GTimer * click_timer = NULL;
 gdouble dbl_click_time;
@@ -619,12 +619,16 @@ gint
 bj_event_enter_notify (GtkWidget *widget, GdkEventCrossing *event, void *d)
 {
   gtk_widget_grab_focus (playing_area);
+
+  return TRUE;
 }
 
 gint
 bj_event_expose_callback (GtkWidget *widget, GdkEventExpose *event, void *d)
 {
   bj_draw_refresh_screen ();
+
+  return TRUE;
 }
 
 gint
