@@ -341,6 +341,10 @@ bj_game_eval_installed_file (gchar *file)
       if (g_file_test (installed_filename, G_FILE_TEST_EXISTS))
         use_cache = true;
 
+      // This is a quick and very, very, dirty fix for 2.4 to make
+      // sure that we work on all architectures (see bug #132486).
+      use_cache = false;
+
       if (! use_cache)
         splash_new ();
       strategy = new LoadablePlayer (numDecks, rules, 
